int image2d_ex() // 2d image example.
{
  const uint32_t size_x = 512;
  const uint32_t size_y = 512;
  int dd = sc_tdc_init_inifile("tdc_gpx3.ini"); //init the hardware and get device descriptor
  if (dd < 0) {
    char error_description[ERRSTRLEN];
    sc_get_err_msg(dd, error_description);
    printf("error! code: %d, message: %s\n", dd, error_description);
    return dd;
  }
  struct sc_pipe_dld_image_xy_params_t prms;
  memset(&prms, 0, sizeof(prms));
  prms.depth = BS32; //4 bytes per pixel in the image
  prms.channel = -1; //all channels together
  prms.binning = {1, 1, 1};
  prms.roi = {{0,0,0}, {size_x, size_y, -1}};
  int pd = sc_pipe_open2(dd, DLD_IMAGE_XY, (void *)&prms); //init image 2d pipe and get pipe descriptor
  //can be called several times with different parameters if necessary
  if (pd < 0) {
    char error_description[ERRSTRLEN];
    sc_get_err_msg(pd, error_description);
    printf("error! code: %d, message: %s\n", pd, error_description);
    sc_tdc_deinit2(dd);
    return pd;
  }
  int ret = sc_tdc_start_measure2(dd, 200); //start 200 ms measure
  if (ret < 0) {
    char error_description[ERRSTRLEN];
    sc_get_err_msg(ret, error_description);
    printf("error! code: %d, message: %s\n", ret, error_description);
    sc_pipe_close2(dd, pd);
    sc_tdc_deinit2(dd);
    return ret;
  }
  uint32_t *image;
  //This will unblock when exposure finished. image will be set to internally
  // allocated image data. Size of the image is roi_x  * roi_y * 4
  // Here it will be 512 * 512 * 4 (see prms.roi and prms.depth settings).
  // Deallocation happens when next sc_pipe_read2(), sc_pipe_close2() or
  //sc_tdc_deinit2() call.
  ret = sc_pipe_read2(dd, pd, (void **) &image, UINT32_MAX);
  if (ret < 0) {
    char error_description[ERRSTRLEN];
    sc_get_err_msg(ret, error_description);
    printf("error! code: %d, message: %s\n", ret, error_description);
    sc_pipe_close2(dd, pd);
    sc_tdc_deinit2(dd);
    return ret;
  }
  // Here application should do necessary actions with the image.
  for (size_t i=0; i<size_x * size_y; ++i) {
    fprintf(stderr, "%08x\n", image[i]);
  }
  sc_pipe_close2(dd, pd);
  sc_tdc_deinit2(dd);
  fprintf(stderr, "\n");
  return 0;
}


