//c99 compiler must be used
#include <scTDC.h>
#include <stdio.h>
int main()
{
  int dd = sc_tdc_init_inifile("tdc_gpx3.ini");
  if (dd < 0) { // could not initialise hardware. dd contains error code
    char error_description[ERRSTRLEN];
    sc_get_err_msg(dd, error_description);
    puts(error_description);
    return dd;
  } else { //dd is device descriptor which could be used for any other operation
    double tdc_binsize;
    int ret = sc_tdc_get_binsize2(dd, &tdc_binsize);
    if (ret < 0) { //if there is error happened.
      puts("could not get binsize");
      return ret;
    }
    printf("tdc binsize is %lf\n", tdc_binsize);
    //now lets try to open tdc_histo pipe
    struct sc_pipe_tdc_histo_params_t params;
    params.depth = BS32; // 32 bit per time channel (point) in the histogram
    params.channel = 0; // pipe for channel #0 is requested
    params.modulo = 0; // modulo is off
    params.binning = 4; // histogram binning is set to 4
    params.offset = 1000; // histogram starts from the 1000 time bins (see sc_tdc_get_binsize2()).
    params.size = 2000; // histogram size is 2000 time bins (but note binning)!
    params.accumulation_ms = 0; // accumulation is off
    params.allocator_owner = NULL; // parameter for allocator cbf
    params.allocator_cb = NULL; // internal allocator is used
    int pipe_id = sc_pipe_open2(dd, TDC_HISTO, (void *)&params);
    if (pipe_id < 0) { //pipe_id contains error code
      char error_description[ERRSTRLEN];
      sc_get_err_msg(pipe_id, error_description);
      puts(error_description);
      return pipe_id;
    }
    sc_tdc_start_measure2(dd, 1000); //start 1000 ms measure
    unsigned *tdc_histo;
    ret = sc_pipe_read2(dd, pipe_id, (void *)&tdc_histo, -1); //after the call
    //tdc_histo pointer will point on the histogram data. The place for the
    //histogram will be allocated by internal allocator and will be destroyed
    //at next call. -1 means wait infinitely (2^32 milliseconds).
    if (ret < 0) { //note that this could be timeout as well
      char error_description[ERRSTRLEN];
      sc_get_err_msg(pipe_id, error_description);
      puts(error_description);
      return ret;
    }
    //now we have data, may process it or show somewhere
    sc_pipe_close2(dd, pipe_id);
    //here data pipe is closed. NOTE: tdc_histo now points to nowhere. If
    //application needs tdc_data at this point - copy it before calling
    //sc_pipe_close2().
    sc_tdc_deinit2(dd); // release hardware and resources.
    return 0;
  }
}

